==> whmcs-8.7.2-release.1.zip: modules/registrars/centralnic/resources/index.php <==
<?php //ICB0 72:0 81:1050                                                     ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.7.2 (8.7.2-release.1)                                      *
// * BuildId:5e9b2f1.301                                                  *
// * Build Date:25 Apr 2023                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPmvnSNrRt4bpKiBaNabLJs6kaG2tli5j4Qd8fXrWfu1CwoA8NPKGjfS9tKx99e7ZPaHzVWZV
hz2wInWYcWJE0rjHlebQZh4BZfr9lWFasYP635slO/tH0DdUOUEZSxA7J0WK/9Heu9lG592Wx6+f
YyoEJ9jyKVT+jeQcCCSiHjsKkNjevwozbty/Vbkw/snoLG6a2bPkTJ5v35svScV+zq+gQj3rOulr
Ax9wjyupCDV4MleXoHf6jGItRHS7Gy4PpSAeXm5mDoghk1E5VoZQcXFWqSlHn1w+4XIYAHHqdMCO
K5HtRlevispY6OqBIbyJTuc7AaE80AERk6FvMRCJ/aoUrwps9o+3VJ3zUUWd1Yfl4O6Vt5J74CRJ
IrLrgDACqqfKHB6bXF7Wq7FKBPJ8bUZhvts4hC4QYhLwE4neFOUdHNOVfdP8bzkg4B3UoQm03aUj
qExq0/3CVqbYG88H1BptODE8WQ4sHVdyDrxgpKKJyvvsclTDWdU51oteqP2zbvdB2IBdnjJ+e264
dn4efz4lQLfSBvrmBjqMQQ9q1B4LZ5qvPAX12ZuxwbDv6bFSlLbC4O9Swmalm1q8kQpTefOQypO8
zbnen/JX1+j1e4p25PULrXqj1TEKQBquUIcXxa/IIZbNCPXqEElaN6a6K4dYqcEWmN01Lg0Qeetq
qQry0J/ItjzsxX52vgpMO14KiHwlZQ4s4Gbh3kii7CgFMxNVSh2xnOmfr2zlnvTUzr1r5djsKjwQ
D89nNNiayaDNjiYjTwVu9m4V/dGQ6PD0tJ8penlafw01EzWOWpUglfvTOE4DJO7yxYDUqIDOXKRT
EPcHP3eGXk3IYxQnR1GAt2xFe+V+jbZ8q2F0xhxplWytOlFjjNtJlUHAUpQe3w7jrR8X=
HR+cPxjT1DS5l/mOeEEHz6sWDOZN8hRWprdqcEmLineZ+s8FVl0BdyCl1+/p7iDixazFlBBVGPZI
Z4p60xyLLs3WpSLR6InrxFSOZ+/lyGsfox6waLUqmzlIZ2o8xWQxzJ+4GvdPinafYH2pVNADfB0N
pjvUiEYUxuclwemCZS9nu4OCUjqR0+goG+xH/IhJzEDPci8TqAs8zK0JE/fUuG43T7aeDJOSJ100
/3lJUuRbzKjJDYRNM5rZqgg1cv78DqpNWz4Lt2gVuD13MCy4SMK2hAoTk9e0bcHG2GMJprdbzalc
NrzIUtV6jcQ+upq3cPAmEO2ETth/vAhqt1pBH74u9dR5IK5/gORz1W2kprD9dHCxynYEHIHrpWkM
jfuEUkV/NRpu+mvS3+ZNf3FMUl3PSVtlP9nrpu6qbAJJKSYjc1WbSK2x8I/Ufj8O124BagiKHG2y
aGqvlI2MyJFzUuHstaSC5yQbaJM8uaOlo4a68Rvc5nccQ0lV0T1B21x5w0HJ2Sb3X8vAzLSG9Qpl
A3H5sErkLkGkU4ghKISZzMNHENUDf94axMPlpMa/646C/hSlw1SmVCslR/UsxjrIdUwDi1XYO/sn
m/70BdT2t6tGAnhYLsiPiYXye35q1rIsb/27Gt/mNF/wEphrY084UBNqejdVQabkIJzrnTURfJwV
6syaBn3bwYTaa5XV9S4qtdBSNYmnBTJwIxemrtkI4YYGDUV4fV59PSQ53Gc5zA65mTPRVqy+NoI9
P31YwyQOMJ7P5YRLQ2XDQoOZPG/hiKDoPvrwGjp6bN7vAu7/BM09tPXZtxnR4yu5XXyHA8GZud5A
+rvEZQ0pJzE3ihQqDmZP/lDzraAHOTpDT3X7raCU7V4M0fpHc7AfXgKWawoXBiySoW==

==> whmcs-8.10.0-release.1.zip: modules/registrars/centralnic/resources/index.php <==
<?php //ICB0 72:0 81:1050                                                     ?><?php //00cb7
// *************************************************************************
// *                                                                       *
// * WHMCS - The Complete Client Management, Billing & Support Solution    *
// * Copyright (c) WHMCS Ltd. All Rights Reserved,                         *
// * Version:8.10.0 (8.10.0-release.1)                                    *
// * BuildId:dc9095d.372                                                  *
// * Build Date:23 Apr 2024                                               *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * Email: info@whmcs.com                                                 *
// * Website: http://www.whmcs.com                                         *
// *                                                                       *
// *************************************************************************
// *                                                                       *
// * This software is furnished under a license and may be used and copied *
// * only  in  accordance  with  the  terms  of such  license and with the *
// * inclusion of the above copyright notice.  This software  or any other *
// * copies thereof may not be provided or otherwise made available to any *
// * other person.  No title to and  ownership of the  software is  hereby *
// * transferred.                                                          *
// *                                                                       *
// * You may not reverse  engineer, decompile, defeat  license  encryption *
// * mechanisms, or  disassemble this software product or software product *
// * license.  WHMCompleteSolution may terminate this license if you don't *
// * comply with any of the terms and conditions set forth in our end user *
// * license agreement (EULA).  In such event,  licensee  agrees to return *
// * licensor  or destroy  all copies of software  upon termination of the *
// * license.                                                              *
// *                                                                       *
// * Please see the EULA file for the full End User License Agreement.     *
// *                                                                       *
// *************************************************************************
if(extension_loaded('ionCube Loader')){die('The file '.__FILE__." is corrupted.\n");}echo("\nScript error: the ".(($cli=(php_sapi_name()=='cli')) ?'ionCube':'<a href="https://www.ioncube.com">ionCube</a>')." Loader for PHP needs to be installed.\n\nThe ionCube Loader is the industry standard PHP extension for running protected PHP code,\nand can usually be added easily to a PHP installation.\n\nFor Loaders please visit".($cli?":\n\nhttps://get-loader.ioncube.com\n\nFor":' <a href="https://get-loader.ioncube.com">get-loader.ioncube.com</a> and for')." an instructional video please see".($cli?":\n\nhttp://ioncu.be/LV\n\n":' <a href="http://ioncu.be/LV">http://ioncu.be/LV</a> ')."\n\n");exit(199);
?>
HR+cPolOAVnu9vBpTMkytn74bm+Rj5XxT7n4CvB8vQW4cV7hLZ1Fx8oBHffxBY30Hp3tOke28U6i
XlbuS7X36EJbGpI7tLC23eJDZnZvbzvvnlPnC0RkjJ4BZB/NmjSQRcNe+mz7R2OzeYl3RIu2bDQZ
V6X+Nr2N9rEkyT3CxkYjOmgZX2v7qW+MiASW2V40bPolT6gk1JYaGJvt0lPsTEFfdLGA+7JeCD1n
7wmGEoQOLLEP4iDtXJSLmCCBYvSaXyiwRTmLC1b95rXpHMemx96uBqylHGK0PbI3iCDwYuOXe69X
MCa4QwwNnq3uR61QREmq4A9A5jeleTVgOvdST6+yYSYL5a37YmOoYiyES40LW956G2bN00lJk7cJ
lp1NgXt3lhBTJWSnIi9yNlWvMVR5P4CoqSFp1OAx0ndnC8YH/R+mg5xeTemdc1BeYh29vWuD7Nyd
RlLFOxooyt9+7gXIksGl7UhD53YgvUdYhXD690wMCeRF4zQlykp+7wtR2gtiJ/ny2gOKNem9WQ1b
jRfHGlkcNME1PwTzyjobdiOGZJEWxi4I4aDDmtFd6aY9LBC6od9Hl0/9UalwcqEcQ8OZh+pL4BhN
0xBW1IbWlIJ8+9Ro2IHJ2a7mnf9lSOkCsrwCuEe0aDF/OUjNId/aDQCAQxQ3f9kYfPXJeyRvu5oQ
cG5mouzstDP1HvoCP5PQY/7DMQLKjKRTpD1cmSnUmsrmnMJKZBGEMhDZZzY5Q1nMwtE/2g93+gLV
GDmW6yIdKmRTH3cbA3SdtDVIRlgc3F/hfku7ZSwP2JVFt4Snb3fbCcxwN4BBgy7WVonrqkjlJYCF
FZ6UwQzPfqun5sccihSMd50tDWAIm71oLUEq4aJ7cu4rBCmhB7d4z9Z/SAg/1DWEbG===
HR+cPr7IhVCa9XR4GMmuqBGKLar/z5BWs2LgllboTiH32Oe+t77tb0Hx272QoupVunn8llVfyKgM
LHOTw4JGC63NGBUqv26kMKde9nMKWyaXT0T0CWb2RnrOGYb+8Km4KAQ7G03QXIWmdWKpl5r6Z7eU
xaprKqYKwkFe5ynxBEfdAK8lyriSYmceGnjfRFxbgLKKDbBfVmokCzsqCJez22wPH4Q6ef1yLFJP
BLV5mmd856NAR1n+h24QCGtLVqmdbgnikBF3TCL30o64r3P4sgcA0tZN4wFjDSQD9wAawhQL8MRH
4WzDhsTmqz4aSzwzACJK2pduQnLE98B6i00YhZ7aXHDsQYhVVkDryZfiolF4XHY2/bmYiMIfgRN9
+JGDIiFCLTrM3Gs330d4z5DTZ6e2yHVG93sPjJhKg4Y/BmhT8EIj54JgbIiLSe5k29e3KmCJGWr1
KuNgV01yG0MBxlt9avep0b7CJoCzqsZo9D9iRLhz/3RjzPd2p1/EmnH6GAlJjpstEfEajwRYT/s6
PpjYB+/WfnhGZdawOjc0n1W5D8LRBbuAlogLikwGAhbIzsFjUyGUEzqaSj3EQvLsR3q3HFgKgKRG
b9zrnocQGJdx9ndHu0AUxiky0IB2ScEdJy5kRFMNYtNb90Tp+lwhf04zVxstBmYsCl0HWSzWG31T
681qsA+P4JORKZaxpEvmJH2V1g+Bef4sgDXyJCkiv4QAUXblp8BM2iC4c5j1rHQ0jm4eTyQMLM6U
zLwnCJujt0Wv5PjeqoZ1pgCX7edjPem9wwK2JkbkZxSfVO7TJaZh9eqO7cHFqzv8gyiWXgL44jOW
92h9iqtndiULP49nKHJQXpWu7Sf5Q8B56AhiFaI9wNzBKnNXcM9mUcmqaZ9pR230L0Wqg5U/zCnf
cW==
